﻿using System.Collections.Generic;
using System.Reflection;
using Funq;
using MyFramework.ServiceStackApi;
using ServiceStack.ServiceHost;
using ServiceStackApiDemo.Domain;
using ServiceStackApiDemo.Facades;
using ServiceStackApiDemo.Queries;

namespace ServiceStackApiDemo.Web
{
    public class DemoAppHost : LelibreAppHost
    {
        public DemoAppHost() : base("Demo Web Services", typeof(MyUserService).Assembly) { }

        protected override IEnumerable<Assembly> Queries
        {
            get
            {
                return new[] 
                { 
                    typeof(IMyUserRepository).Assembly,
                    typeof(LelibreUserAuthRepository).Assembly, 
                };
            }
        }

        protected override IEnumerable<Assembly> Factories
        {
            get
            {
                return new[] 
                {
                    typeof(LelibreUserAuthRepository).Assembly,
                    typeof(IMyUser).Assembly
                };
            }
        }

        protected override IEnumerable<Assembly> Mappers
        {
            get
            {
                return new[] { typeof(MyUserService).Assembly };
            }
        }

        protected override IEnumerable<Assembly> Facades
        {
            get
            {
                return new[] { typeof(IMyUserFacade).Assembly };
            }
        }

        protected override IEnumerable<Assembly> Validators
        {
            get
            {
                return new[] { typeof(CreateUserValidator).Assembly };
            }
        }

        public override void Configure(Container container)
        {
            base.Configure(container);
            this.Config.EnableFeatures = Feature.Jsv | Feature.Csv | Feature.Json;
        }

        public override IServiceRunner<TRequest> CreateServiceRunner<TRequest>(ServiceStack.WebHost.Endpoints.ActionContext actionContext)
        {
            return base.CreateServiceRunner<TRequest>(actionContext);
        }
    }
}
